@@ -1,4 +1,4 @@
-### efront.R  (2008-10-27)
+### efront.R  (2008-11-19)
 ###
 ###    Efron t Statistic (2001)
 ###
@@ -32,23 +32,20 @@ efront.stat = function (X, L, verbose=TRUE)
 
 efront.fun <- function (L, verbose=TRUE)
 {
-    if (missing(L)) stop("class labels are missing!")
-    L = factor(L)
-    cl = levels(L)
-    if (length(cl) != 2) stop("class labels must be specified for two groups, not more or less!")
-    idx1 = (L == cl[1])
-    idx2 = (L == cl[2])
+    if (missing(L)) stop("Class labels are missing!")
 
     function(X)
     {
-      tmp = pvt.group.moments(X, idx1, idx2, variances=TRUE)
+      tmp = centroids(X, L, var.pooled=TRUE, var.groups=FALSE, shrink=FALSE, verbose=verbose)
       
       # differences between the two groups
-      diff = tmp$mu1-tmp$mu2
+      diff = tmp$means[,1]-tmp$means[,2]
       
       # standard error of diff
-      n1 = sum(idx1); n2 = sum(idx2)      
-      sd = sqrt( (1/n1 + 1/n2)*tmp$v.pooled )
+      n1 = tmp$samples[1]
+      n2 = tmp$samples[2]
+      v =  tmp$var.pooled   
+      sd = sqrt( (1/n1 + 1/n2)*v )
       
       # tuning parameter
       a0 <- quantile(sd, probs=c(0.9))
