@@ -36,10 +36,10 @@ sam.fun <- function(L)
 {
    require("samr")
 
-    if (missing(L)) stop("class labels are missing!")
+    if (missing(L)) stop("Class labels are missing!")
     L = factor(L)
     cl = levels(L)
-    if (length(cl) != 2) stop("class labels must be specified for two groups, not more or less!")
+    if (length(cl) != 2) stop("Class labels must be specified for two groups, not more or less!")
   
    function(X)
     {
